# FakeDB

FakeDB is a simple, fast and persistent key-value store for small nodejs applications. Eventually,
FakeDB will also support simple queries and maybe even indexing.

## Installation

```
npm install fakedb
```

## Example Code

``` js
var should = require('should'),
    db = require('fakedb').init('test.fakedb');

var data = [
  { username: 'jaydee', password: 'secret' },
  { username: 'sheryl', password: 'secret' },
  { username: 'addie', password: 'secret' },
  { username: 'oliver', password: 'secret' },
  { username: 'aleksees', password: 'secret' },
  { username: 'andee', password: 'secret' },
  { username: 'becky', password: 'secret' },
  { username: 'ernesto', password: 'secret' }
];

db.on('load', function () {
  
  console.log('Records loaded, starting tests...');

  data.forEach(function (obj) {
    db.set(obj.username, obj);
  });

  db.count().should.equal(data.length);

  data.forEach(function (obj) {
    db.get(obj.username, function (record) {
      should.exist(record);
      record.should.have.property('key');
      record.should.have.property('value');
      record.value.should.have.property('username', obj.username);
      record.value.should.have.property('password', obj.password);
    });
  });

  db.all(function (records) {
    should.exist(records);
    records.should.have.property('length', data.length);
  });

  db.all(function (records) {
    should.exist(records);
    records.should.have.property('length', 2);
  }, { offset: 0, limit: 2 });

  db.first(function (record) {
    should.exist(record);
    record.should.have.property('value');
    record.value.should.have.property('username', 'jaydee');
  });

  db.last(function (record) {
    should.exist(record);
    record.should.have.property('value');
    record.value.should.have.property('username', 'ernesto');
  });

  data.forEach(function (obj) {
    db.remove(obj.username);
    db.get(obj.username, function (record) {
      record.should.not.exist();
    });
  });

  console.log('Tests completed!');
});

db.on('drain', function () {
  console.log('Log entries saved to disk.');
});

db.on('error', function (err) {
  console.log('Error encountered -- ' + err);
});
```

## Testing

A simple test script is provided in the test folder. To run this script, `should.js` needs to be installed.

```
npm install should
```

## License

(The MIT License)

Copyright (c) 2011 Jesus A. Domingo <jesus.domingo@gmail.com>

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the 'Software'), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED 'AS IS', WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
