var should = require('should'),
    db = require('../lib/fakedb').init('test.fakedb');

var data = [
  { username: 'jaydee', password: 'secret' },
  { username: 'sheryl', password: 'secret' },
  { username: 'addie', password: 'secret' },
  { username: 'oliver', password: 'secret' },
  { username: 'aleksees', password: 'secret' },
  { username: 'andee', password: 'secret' },
  { username: 'becky', password: 'secret' },
  { username: 'ernesto', password: 'secret' }
];

db.on('load', function () {
  
  console.log('Records loaded, starting tests...');

  data.forEach(function (obj) {
    db.set(obj.username, obj);
  });

  db.count().should.equal(data.length);

  data.forEach(function (obj) {
    db.get(obj.username, function (record) {
      should.exist(record);
      record.should.have.property('key');
      record.should.have.property('value');
      record.value.should.have.property('username', obj.username);
      record.value.should.have.property('password', obj.password);
    });
  });

  db.all(function (records) {
    should.exist(records);
    records.should.have.property('length', data.length);
  });

  db.all(function (records) {
    should.exist(records);
    records.should.have.property('length', 2);
  }, { offset: 0, limit: 2 });

  db.first(function (record) {
    should.exist(record);
    record.should.have.property('value');
    record.value.should.have.property('username', 'jaydee');
  });
  
  db.last(function (record) {
    should.exist(record);
    record.should.have.property('value');
    record.value.should.have.property('username', 'ernesto');
  });

  data.forEach(function (obj) {
    db.remove(obj.username);
    db.get(obj.username, function (record) {
      record.should.not.exist();
    });
  });

  console.log('Tests completed!');
});

db.on('drain', function () {
  console.log('Log entries saved to disk.');
});

db.on('error', function (err) {
  console.log('Error encountered -- ' + err);
});
